@@ -9,25 +9,19 @@ makeArgs <- function(obj, termNames, comb, opt, ...) UseMethod("makeArgs", obj)
 }
 
 makeArgs.default <- function(obj, termNames, comb, opt, ...) {
-	reportProblems <- c()
-	termNames0 <- termNames
-
+	reportProblems <- character(0L)
 	termNames[termNames %in% opt$interceptLabel] <- "1"
-	f <- reformulate(c(if(!opt$intercept) "0", termNames), response=opt$response)
+	f <- reformulate(c(if(!opt$intercept) "0", termNames), response = opt$response)
 	environment(f) <- opt$gmFormulaEnv
 	ret <- list(formula = f)
 	if(!is.null(opt$gmCall$start)) {
 		coefNames <- fixCoefNames(.getCoefNames(f, opt$gmDataHead,
 			opt$gmCall$contrasts, envir = opt$gmEnv))
-
 		idx <- match(coefNames, opt$gmCoefNames)
-
-		if(any(is.na(idx))) {
-			reportProblems <- append(reportProblems, "cannot subset 'start' argument. Coefficients in generated model do not exist in the global model")
-		} else {
-			ret$start <- substitute(start[idx], list(start = opt$gmCall$start,
+		if(any(is.na(idx))) reportProblems <-
+			append(reportProblems, "cannot subset 'start' argument. Coefficients in generated model do not exist in the global model")
+		else ret$start <- substitute(start[idx], list(start = opt$gmCall$start,
 			idx = idx))
-		}
 	}
 	attr(ret, "formulaList") <- list(f)
 	attr(ret, "problems") <- reportProblems
@@ -36,12 +30,13 @@ makeArgs.default <- function(obj, termNames, comb, opt, ...) {
 
 makeArgs.gls <- function(obj, termNames, comb, opt, ...) {
 	ret <- makeArgs.default(obj, termNames, comb, opt)
-	names(ret)[1] <- "model"
+	names(ret)[1L] <- "model"
 	ret
 }
+
 makeArgs.lme <- function(obj, termNames, comb, opt, ...) {
 	ret <- makeArgs.default(obj, termNames, comb, opt)
-	names(ret)[1] <- "fixed"
+	names(ret)[1L] <- "fixed"
 	ret
 }
 
@@ -71,7 +66,7 @@ makeArgs.mer <- function(obj, termNames, comb, opt, ...) {
 # This works for all the child classes provided that the arguments containing
 # formulas are named *formula, and they are at the beginnning of the call, and
 # if there is no more than 6 of them, and if there is a single 'formula'
-# argument, it is double-one-sided.
+# argument it is doubly-one-sided.
 # Guessing the argument names is only negligibly slower than when they are
 # provided to the function, so the methods for child classes are commented out.
 
@@ -81,14 +76,14 @@ makeArgs.mer <- function(obj, termNames, comb, opt, ...) {
 	...) {
 	zarg <- .makeUnmarkedFitFunnyFormulas(termNames, opt, fNames)
 	if(missing(formula.arg)) { # fallback
-		nm <- names(opt$gmCall)[-1]
-		formula.arg <- nm[grep(".*formula$", nm[1:7])]
+		nm <- names(opt$gmCall)[-1L]
+		formula.arg <- nm[grep(".*formula$", nm[1L:7L])]
 		#print(formula.arg)
 	}
 	if(length(formula.arg) == 1L && formula.arg == "formula") {
 		i <- sapply(zarg, is.null)
 		zarg[i] <- rep(list(~ 1), sum(i))
-		ret <- list(formula = call("~", zarg[[2]], zarg[[1]][[2]]))
+		ret <- list(formula = call("~", zarg[[2L]], zarg[[1L]][[2L]]))
 		attr(ret, "formulaList") <- zarg
 		ret
 	} else {
@@ -111,6 +106,25 @@ function(obj, termNames, comb, opt, ...)  {
 	ret
 }
 
+`makeArgs.zeroinfl` <- function(obj, termNames, comb, opt, ...) {
+	i <- termNames %in% opt$interceptLabel
+	termNames[i] <- gsub("(Intercept)", "1", termNames[i], fixed = TRUE)
+	pos <- regexpr("_", termNames, fixed = TRUE)
+	zarg <- lapply(split(substring(termNames, pos + 1L, 256L),
+		substring(termNames, 1L, pos - 1L)), function(x)
+			formula(terms.formula(reformulate(as.character(x)),
+				simplify = TRUE)))
+	zarg <- lapply(zarg, `environment<-`, opt$gmFormulaEnv)
+	fnames <- c("count", "zero")
+	zarg <- zarg[fnames]
+	names(zarg) <- fnames
+	fexpl <- zarg$count[[2L]]
+	if(!is.null(zarg$zero)) fexpl <- call("|", fexpl, zarg$zero[[2L]])
+		else zarg$zero <- NULL
+	ret <- list(formula = call("~", opt$response, fexpl))
+	attr(ret, "formulaList") <- zarg
+	ret
+}
 
 #`makeArgs.unmarkedFitColExt` <- function(obj, termNames, comb, opt, ...)
 #	makeArgs.unmarkedFit(obj, termNames, comb, opt, c("psi", "col", "ext", "p"),
